==> revit-family-web-viewer-0.3.0.tgz: package/README.md <==
Revit Family (.rfa) Web Viewer
=====================

[![Three.js](https://img.shields.io/badge/three.js-Revit-5D8CAE.svg)](https://threejs.org/)
[![License](https://img.shields.io/github/license/OpenHoReCa/revit-web-viewer.svg)](https://www.gnu.org/licenses/gpl-3.0.en.html)
[![Git_tag](https://img.shields.io/github/tag/OpenHoReCa/revit-web-viewer.svg?colorB=8e8c5a)](https://github.com/OpenHoReCa/revit-web-viewer/tags)
[![Language](https://img.shields.io/github/languages/top/OpenHoReCa/revit-web-viewer.svg?colorB=0f6f6f&maxAge=3600)](https://github.com/OpenHoReCa/revit-web-viewer/search?l=typescript)

Revit Family Web Viewer is a Three.js-based project viewer. Revit projects / families must be exported using [RvtVa3c exporter](https://github.com/va3c/RvtVa3c)

![Usage demo](./demo/assets/unox_demo.gif)

# License
Revit Family Web Viewer is licensed under [GPLv3 license](https://github.com/OpenHoReCa/revit-web-viewer/blob/master/LICENSE), which is a [viral license](https://en.wikipedia.org/wiki/Viral_license), therefore you can use it applications distributed under the *SAME* (GPL) or compatible licenses. In most scenarios Revit Family Web Viewer **CAN'T** be distributed as part of a **proprietary** applications, even if you do not change it or charge money for you application.
Please contact [CodeCave, PUE](https://codecave.pro/contact-us/) for further information.


# Credits

Revit Family Web Viewer is inspired by [Va3c viewer](https://github.com/va3c/viewer), so part of credits go to it developers.

==> revit-family-web-viewer-0.3.1.tgz: package/README.md <==
Revit Family (.rfa) Web Viewer
=====================

[![Three.js](https://img.shields.io/badge/three.js-Revit-5D8CAE.svg)](https://threejs.org/)
[![License](https://img.shields.io/github/license/OpenHoReCa/revit-web-viewer.svg)](https://www.gnu.org/licenses/gpl-3.0.en.html)
[![Git_tag](https://img.shields.io/github/tag/OpenHoReCa/revit-web-viewer.svg?colorB=8e8c5a)](https://github.com/OpenHoReCa/revit-web-viewer/tags)
[![Language](https://img.shields.io/github/languages/top/OpenHoReCa/revit-web-viewer.svg?colorB=0f6f6f&maxAge=3600)](https://github.com/OpenHoReCa/revit-web-viewer/search?l=typescript)

Revit Family Web Viewer is a Three.js-based project viewer. Revit projects / families must be exported using [RvtVa3c exporter](https://github.com/va3c/RvtVa3c)

![Usage demo](./assets/unox_demo.gif)

# License
Revit Family Web Viewer is licensed under [GPLv3 license](https://github.com/OpenHoReCa/revit-web-viewer/blob/master/LICENSE), which is a [viral license](https://en.wikipedia.org/wiki/Viral_license), therefore you can use it applications distributed under the *SAME* (GPL) or compatible licenses. In most scenarios Revit Family Web Viewer **CAN'T** be distributed as part of a **proprietary** applications, even if you do not change it or charge money for you application.
Please contact [CodeCave, PUE](https://codecave.pro/contact-us/) for further information.


# Credits

Revit Family Web Viewer is inspired by [Va3c viewer](https://github.com/va3c/viewer), so part of credits go to it developers.
